@@ -12,6 +12,7 @@ use utf8;
 #use Log::Report::Optional 'log-report';
 
 use Unicode::GCString ();
+use Data::Dumper      ();
 use Date::Parse       qw/str2time/;
 use Encode            qw/is_utf8 decode/;
 use HTML::Entities    qw/encode_entities/;
@@ -28,16 +29,18 @@ my @default_modifiers   = (
 	qr/DATE\b/       => \&_modif_date,
 	qr/TIME\b/       => \&_modif_time,
 	qr/\=/           => \&_modif_name,
+	qr!UNKNOWN\([0-9]+\)|UNKNOWN\b!       => \&_modif_unknown,
 	qr!CHOP\([0-9]+(?:\,?[^)]*)\)|CHOP\b! => \&_modif_chop,
 	qr!EL\([0-9]+(?:\,?[^)]*)\)|EL\b!     => \&_modif_ellipsis,
 	qr!//(?:\"[^"]*\"|\'[^']*\'|\w+)!     => \&_modif_undef,
 );
 
 my %defaults = (
-	CHOP   => +{ width => 20, head => '[', units => '', tail => ']' },
-	DT     => +{ standard => 'FT' },
-	EL     => +{ width => 20, replace => '⋯ '},
-	FORMAT => +{ thousands => '' },
+	CHOP      => +{ width => 30, head => '[', units => '', tail => ']' },
+	DT        => +{ standard => 'FT' },
+	EL        => +{ width => 30, replace => '⋯ '},
+	FORMAT    => +{ thousands => '' },
+	UNKNOWN   => +{ width => 30, trim => 'EL' },
 );
 
 my %default_serializers = (
@@ -157,10 +160,10 @@ passed to C<print[ip]> itself.
 =default serializers <useful defaults>
 How to serialize data elements.
 
-=option  encode_for HASH|'HTML'
+=option  encode_for \%rules|'HTML'
 =default encode_for undef
 [0.91] The format string and the inserted values will get encoded according to
-some syntax rules.  Function C<encode_entities()> provided by HTML::Entities
+some %rules.  Function C<encode_entities()> provided by HTML::Entities
 is used when you specify the predefined string C<HTML>.  See M<encodeFor()>
 and L</Output encoding>.
 
@@ -170,9 +173,9 @@ and L</Output encoding>.
 from the parameter list.  In that case, a warning is produced and undef
 inserted.  May can overrule that behavior.
 
-=option  defaults   \%defaults
-=default defaults   C<see modifier docs>
-[1.00] change the defaults for some modifiers.  This is a map of
+=option  defaults \%map
+=default defaults C<see modifier docs>
+[1.00] change the defaults for some modifiers.  This is a %map of
 modifier name to HASH with modifier specific settings.
 
 =examples
@@ -732,10 +735,11 @@ sub _modif_name($$$)
 sub _modif_chop($$$)
 {	my ($self, $format, $value, $args) = @_;
 	defined $value && length $value or return undef;
-	$format =~ m/^ CHOP\( ([0-9]+) \,? ([^)]+)? \) | CHOP\b /x or die $format;
 
 	my $defaults = $self->defaults('CHOP');
-	my ($width, $units) = ($1 // $defaults->{width}, $2 // $defaults->{units});
+	$format =~ m/^ CHOP\( ([0-9]+) \,? ([^)]+)? \) | CHOP\b /x or die $format;
+	my $width    = $1 // $args->{width} // $defaults->{width};
+	my $units    = $2 // $args->{units} // $defaults->{units};
 	$width != 0 or return $value;
 
 	# max width of a char is 2
@@ -771,10 +775,11 @@ sub _modif_chop($$$)
 sub _modif_ellipsis($$$)
 {	my ($self, $format, $value, $args) = @_;
 	defined $value && length $value or return undef;
-	$format =~ m/^ EL\( ([0-9]+) \,? ([^)]+)? \) | EL\b /x or die $format;
 
 	my $defaults = $self->defaults('EL');
-	my ($width, $replace) = ($1 // $defaults->{width}, $2 // $defaults->{replace});
+	$format =~ m/^ EL\( ([0-9]+) \,? ([^)]+)? \) | EL\b /x or die $format;
+	my $width    = $1 // $args->{width}   // $defaults->{width};
+	my $replace  = $2 // $args->{replace} // $defaults->{replace};
 	$width != 0 or return $value;
 
 	# max width of a char is 2
@@ -795,6 +800,29 @@ sub _modif_ellipsis($$$)
 	$v->as_string . $pad . $replace;
 }
 
+sub _modif_unknown($$$)
+{	my ($self, $format, $value, $args) = @_;
+	defined $value or return undef;
+
+	my $defaults = $self->defaults('UNKNOWN');
+	$format =~ m/^ UNKNOWN\( ([0-9]+) \) | UNKNOWN\b /x or die $format;
+	$args->{width} = $1 // $args->{width} // $defaults->{width};
+
+	return ref $value
+		if blessed $value;
+
+	my $trim    = $args->{trim} // $defaults->{trim};
+	my $trimmer = $trim eq 'EL' ? '_modif_ellipsis' : $trim eq 'CHOP' ? '_modif_chop' : die $trim;
+	my $shorten = sub { $self->$trimmer($trim, $_[0], $args) };
+
+	my $serial  = Data::Dumper->new([$value])->Quotekeys(0)->Terse(1)->Useqq(1)->Indent(0)->Sortkeys(1)->Dump;
+
+	  ! reftype $value          ?  '"' . $shorten->($serial =~ s/^\"//r =~ s/\"$//r) . '"'
+	: reftype $value eq 'ARRAY' ?  '[' . $shorten->($serial =~ s/^\[//r =~ s/\]$//r) . ']'
+	: reftype $value eq 'HASH'  ?  '{' . $shorten->($serial =~ s/^\{//r =~ s/\}$//r) . '}'
+	:     $shorten->($serial);
+}
+
 =function printi [$fh], $format, %data|\%data
 Calls M<sprinti()> to fill the %data into $format, and then sends it to
 the $fh (by default the selected file handle)
@@ -1183,10 +1211,17 @@ specify its width, then there is no performance penalty for using 'S'.
   # name right aligned, commas on same position, always
   printp "name: {name%20S},\n", name => $some_chinese;
 
-=subsubsection POSIX modifier extensions '%[+ -0]?[0-9]*[_,.]?d'
+=subsubsection POSIX modifier extensions '%d'
 
-[0.96] Only available when you print (big) decimals: add an underscore,
-comma, or dot on the thousands.
+The full pattern is pretty complex: C<< %[+ -0]?[0-9]*[_,.]?d >>, POSIX
+format style with a few extra features.  The middle (optional) digits tell
+the minimal size of the integer to be displayed.  The optional character
+before it says: C<+> will add a '+' sign when positive, 'blank' adds one
+blank before the digits when positive, a C<0> pads left with zeros instead
+of blanks.  Finally, a C<-> means left-align padding blanks on the right.
+
+[0.96] The last pattern is only useful when you print (big) decimals:
+add an underscore, comma, or dot on the thousands.
 
   printi "{count%_d}\n", count => 1e9;   # 1_000_000_000
   printi "{count%,d}\n", count => 1e9;   # 1,000,000,000
@@ -1365,6 +1400,34 @@ Other defaults are C<head> (C<<[>>) and C<tail> (C<<]>>).
   $sp->setDefaults(CHOP => +{head => '«', tail => '»'});
   $sp->printi("Intro: {text CHOP}", text => $t); # Intro: 1234578«+12»
 
+=subsection Modifier: UNKNOWN or UNKNOWN($width)
+
+[1.01] When you need to interpolate a value which is unknown and potentially
+unsafe, then use this.  For instance, you produce an internal error message
+to report that a method is used incorrectly:
+
+  sub openFolder
+  {  my ($self, $folder) = @_;
+
+     blessed $folder && $folder->isa('Mail::Box')
+        or printi "ERROR: expected a Mail::Box, got a {t UNKNOWN}.",
+              t => $folder;
+  }
+
+Now, this C<$folder> parameter is clearly wrong.  But what is it?  Did we
+pass a wrong object type?  Did we pass a string?  An ARRAY maybe?
+
+The C<UNKNOWN> modifier distibuishes the following:
+=over 4
+=item * undefined values will be shown as the UNDEF serializer does;
+=item * objects will be represented by their type;
+=item * references will show the first part of their Data::Dumper dump; and
+=item * the leading parts of strings will be shown between double quotes.
+=back
+
+Care is taken that weird characters are escaped.  The shortening uses the
+C<trim> setting: either C<'EL'> (default) or C<'CHOP'>.
+
 =subsection Private modifiers
 
 You may pass your own modifiers.  A modifier consists of a selector and
@@ -1419,11 +1482,10 @@ formatter understands where one ends and the next begins.
 The modifiers are called in order:
 
   printi "price: {p€%9s}\n", p => $p; # price: ␣␣␣123.45
-  printi "!{t T%10s}!", t => $now;    # !␣␣12:59:17!
+  printi "!{t TIME%10s}!", t => $now; # !␣␣12:59:17!
 
   printp "price: %9{€}s\n", $p;       # price: ␣␣␣123.45
-  printp "!%10{T}s!", $now;           # !␣␣12:59:17!
-
+  printp "!%10{TIME}s!", $now;        # !␣␣12:59:17!
 
 =section Output encoding
 
@@ -1506,7 +1568,7 @@ Better not to have HTML in your program: leave it to the template.  But
 in some cases, you have no choice.
 
 
-=section String::Print Compared to other modules on CPAN
+=section String::Print compared to other modules on CPAN
 
 There are a quite a number of modules on CPAN which extend the functionality
 of C<printf()>.  To name a few:
